<?php
/*
Plugin Name: BuddyPress Ninja
Plugin URI: http://flweb.it
Description: Site admins can use stealth mode so other user cannot see their last activity (in the future other admin tools may be added, like a swiss-army knife for bp admins )
Version: 0.1
Revision Date: 03 09, 2010
Requires at least: WP 2.9.2, BuddyPress 1.2.1
Tested up to: WP 2.9.2, BuddyPress 1.2.1
License: GNU General Public License 2.0 (GPL) http://www.gnu.org/licenses/gpl.html
Author: Francesco Laffi
Author URI: http://flweb.it
*/

/* Only load the component if BuddyPress is loaded and initialized. */
function bp_ninja_init() {
	add_action( 'init', 'bp_ninja' );
}
add_action( 'bp_init', 'bp_ninja_init' );

function bp_ninja() {
	global $bp,$bp_ninja_options;
	
	if (is_site_admin()){
		$bp_ninja_options = get_usermeta( $bp->loggedin_user->id, 'bp_ninja' );
		
		if ( $bp_ninja_options === '' )
			$bp_ninja_options = array( 'stealth_mode' => false );
			
		if ( isset( $_GET['disable-stealth'] ) && $bp_ninja_options['stealth_mode'] !== false) {
			$bp_ninja_options['stealth_mode'] = false;
			update_usermeta( $bp->loggedin_user->id, 'bp_ninja' , $bp_ninja_options);
		}
			
		if ( isset( $_GET['enable-stealth'] )  && $bp_ninja_options['stealth_mode'] !== true) {
			$bp_ninja_options['stealth_mode'] = true;
			update_usermeta( $bp->loggedin_user->id, 'bp_ninja' , $bp_ninja_options);
		}
		
			
		if ($bp_ninja_options['stealth_mode']){
			//first remove the action that record the last activity
			remove_action( 'wp_head', 'bp_core_record_activity' );
			
			//then remove the last activity
			delete_usermeta( $bp->loggedin_user->id, 'last_activity' );
		}
	
		add_action( 'bp_adminbar_menus', 'bp_ninja_adminbar_menu', 80 );
		
	}
}

// **** Admin bar menu ********
function bp_ninja_adminbar_menu() {
	global $bp,$bp_ninja_options; ?>
	<li id="bp-adminbar-ninja-menu">
		<a href="#"><?php _e( 'Stealth', 'bp-ninja' ) ?></a>
		<ul>
			<?php if ( $bp_ninja_options['stealth_mode'] ) : ?>
			
			<li><a href="?disable-stealth"><?php _e( 'Disable stealth', 'bp-ninja' ) ?></a></li>
			
			<?php else: ?>

			<li><a href="?enable-stealth"><?php _e( 'Enable stealth', 'bp-ninja' ) ?></a></li>

			<?php endif; ?>

			<?php do_action( 'bp_adminbar_ninja_menu' ) ?>
		</ul>
	</li>
	<?php
}

function bp_ninja_delete_user_data( $user_id ) {
	
	delete_usermeta( $user_id, 'bp_ninja' );
	
}
add_action( 'wpmu_delete_user', 'bp_ninja_delete_user_data', 1 );
add_action( 'delete_user', 'bp_ninja_delete_user_data', 1 );


/* Put setup procedures to be run when the plugin is activated in the following function */
function bp_ninja_activate() {
}
register_activation_hook( __FILE__, 'bp_ninja_activate' );

/* On deacativation, clean up anything your component has added. */
function bp_ninja_deactivate() {
	/* You might want to delete any options or tables that your component created. */
}
register_deactivation_hook( __FILE__, 'bp_ninja_deactivate' );
?>